==> haskell-hspec-attoparsec-0.1.0.2-225-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-attoparsec
version:              0.1.0.2
visibility:           public
id:                   hspec-attoparsec-0.1.0.2-DAbnGsyJcKU9h6mNYUmP62
key:                  hspec-attoparsec-0.1.0.2-DAbnGsyJcKU9h6mNYUmP62
license:              BSD-3-Clause
copyright:            2014-2015 Alp Mestanogullari
maintainer:           alpmestan@gmail.com
author:               Alp Mestanogullari
homepage:             http://github.com/alpmestan/hspec-attoparsec
synopsis:
    Utility functions for testing your attoparsec parsers with hspec

description:
    This package provides some helper functions for testing attoparsec parsers with hspec.

    See the documentation in @Test.Hspec.Attoparsec@ for examples, or this package'\''s own test suite.

category:             Testing, Parsing
abi:                  6a0d2c696354fc945a169002dc2b9597
exposed:              True
exposed-modules:      Test.Hspec.Attoparsec Test.Hspec.Attoparsec.Source
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-attoparsec
hs-libraries:         HShspec-attoparsec-0.1.0.2-DAbnGsyJcKU9h6mNYUmP62
depends:
    attoparsec-0.14.4-2y9eL1gxaFn1uCSGoZSkZz base-4.17.2.1
    bytestring-0.11.5.3 hspec-expectations-0.8.3-7XfqTeLar9oB5PR25VWuG3
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-attoparsec/html/hspec-attoparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-attoparsec-0.1.0.2-227-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-attoparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-attoparsec
version:              0.1.0.2
visibility:           public
id:                   hspec-attoparsec-0.1.0.2-F6SmOsvrSwAI2nXoszkTX2
key:                  hspec-attoparsec-0.1.0.2-F6SmOsvrSwAI2nXoszkTX2
license:              BSD-3-Clause
copyright:            2014-2015 Alp Mestanogullari
maintainer:           alpmestan@gmail.com
author:               Alp Mestanogullari
homepage:             http://github.com/alpmestan/hspec-attoparsec
synopsis:
    Utility functions for testing your attoparsec parsers with hspec

description:
    This package provides some helper functions for testing attoparsec parsers with hspec.

    See the documentation in @Test.Hspec.Attoparsec@ for examples, or this package'\''s own test suite.

category:             Testing, Parsing
abi:                  2ecb3789f5792199fd4e7b2e86efd858
exposed:              True
exposed-modules:      Test.Hspec.Attoparsec Test.Hspec.Attoparsec.Source
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-attoparsec-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-attoparsec
hs-libraries:         HShspec-attoparsec-0.1.0.2-F6SmOsvrSwAI2nXoszkTX2
depends:
    attoparsec-0.14.4-62hSVPdjEK0BKtGrIEp0w5 base-4.17.2.1
    bytestring-0.11.5.3 hspec-expectations-0.8.3-7XfqTeLar9oB5PR25VWuG3
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-attoparsec/html/hspec-attoparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-attoparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
